%%% 
%%% This file provides the thesis document of the Chair of Production Management
%%% (Prof. Dr. Raik Stolletz)
%%% University of Mannheim
%%% Maintenance: SMZ
%%% Possible options: 
%%%     en/de: set the language of the thesis to English (en) or German (de)
%%%     seminarthesis/bachelorthesis/masterthesis: Defines the type of thesis    
%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{productionthesis}[2020/11/11 Thesis template of Chair of Production Management]
\LoadClass[a4paper, 12pt]{article}


%%%%%%%%%%%%%% Definition of vairables %%%%%%%%%%%%%%
\newif\if@languageen\@languageentrue
\newif\if@languagede\@languagedefalse
\newif\if@bachelorthesis\@bachelorthesisfalse
\newif\if@seminarthesis\@seminarthesistrue
\newif\if@masterthesis\@masterthesisfalse
\newcommand{\supervisor}[1]{\def\@supervisor{#1}}
\newcommand{\firstaddressline}[1]{\def\@firstaddressline{#1}}
\newcommand{\secondaddressline}[1]{\def\@secondaddressline{#1}}
\newcommand{\submissiondate}[1]{\def\@submissiondate{#1}}
\newcommand{\matrnr}[1]{\def\@matrnr{#1}}
\newcommand{\thesisterm}[1]{\def\@thesisterm{#1}}
\newcommand{\thesisyear}[1]{\def\@thesisyear{#1}}
%%%%%%%%%%%%%%%End of definition of variables%%%%%%%%


%%%%%%%%%%%%%% Processing options %%%%%%%%%%%%%%%%%%%%%%
\DeclareOption{en}{\@languageentrue}
\DeclareOption{de}{\@languagedetrue\@languageenfalse}
\DeclareOption{bachelorthesis}{\@bachelorthesistrue}
\DeclareOption{seminarthesis}{\@seminarthesistrue}
\DeclareOption{masterthesis}{\@masterthesistrue}
\ProcessOptions\relax
%%%%%%%%%%%%% End of processing options %%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%% Loading packages %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\if@languagede
    \RequirePackage[ngerman]{babel}
\else
    \RequirePackage[english]{babel}
\fi
\RequirePackage[utf8]{inputenc}
\RequirePackage{graphicx}
\RequirePackage{amsmath,amssymb}
\RequirePackage{natbib}
\RequirePackage{setspace}
\RequirePackage[left=35mm,right=25mm,top=25mm,bottom=20mm,includeheadfoot]{geometry}
\RequirePackage[notindex,nottoc]{tocbibind}
\RequirePackage{listings}
\RequirePackage{xstring}
%%%%%%%%%%%%%%% End of loading packages %%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%% New Commands %%%%%%%%%%%%%%%%%%%%%%%%%%
\newif\if@firstappendix\@firstappendixtrue
\newcommand{\thesisappendix}[1]{
    \if@firstappendix
        \newpage
        \pagenumbering{Roman}
        \setcounter{page}{\value{roman}}
        \if@languagede
            \section*{Anhang}
            \addcontentsline{toc}{section}{Anhang}
        \else
            \section*{Appendix}
            \addcontentsline{toc}{section}{Appendix}
        \fi
        \@firstappendixfalse
    \fi
    \subsection*{#1}
}
%%%%%%%%%%%%%%%% End of new commands %%%%%%%%%%%%%%%%%%%


%indention at the beginning of paragraphs
\setlength{\parindent}{0pt}

%space between paragraphs
\setlength{\parskip}{6pt}

%page layout (not to be changed!)
% \topmargin -11mm
% \textheight 254mm
% \textwidth 158mm
\footskip 10mm
\voffset -0.5cm
\hoffset -0.5cm

\AtBeginDocument{
    \onehalfspacing

    %page numbering: small roman numbers (i, iv): roman
    %page numbering: capital roman numbers (I, IV): Roman
    \pagenumbering{Roman}

    %no page number on the title page
    \thispagestyle{empty}
    
    \if@languagede
        Universität Mannheim\\
        Fakultät für Betriebswirtschaftslehre\\
        Lehrstuhl für ABWL und Produktion\\
        Prof. Dr. Raik Stolletz\\
        \@supervisor
    \else
        University of Mannheim\\
        Business School\\
        Chair of Production Management\\
        Prof. Dr. Raik Stolletz\\
        \@supervisor
    \fi

    \vspace{1cm}

\begin{center}
    \if@languagede
        \includegraphics[width=.5\paperwidth]{img/04_Logo_Fakultaet_BWL_DE_RGB.png}
    \else
        \includegraphics[width=.5\paperwidth]{img/04_Logo_Fakultaet_BWL_EN_RGB.png}
    \fi
    
    \vspace{1cm}

    \if@languagede
        \if@bachelorthesis
            Bachelorarbeit
        \else
            \if@masterthesis
                Masterarbeit
            \else
                Seminararbeit\\
                im Rahmen des Forschungsseminars OPM 761 (\@thesisterm \@thesisyear)
            \fi
        \fi
    \else
        \if@bachelorthesis
            Bachelor Thesis
        \else
            \if@masterthesis
                Master Thesis
            \else
                Term paper\\
                for the research seminar OPM 761 (\@thesisterm~term~\@thesisyear)
            \fi
        \fi
    \fi

\vspace{2.2cm}

{\Large \@title}
\end{center}

\vspace{4cm}

\@author\\
\@firstaddressline\\
\@secondaddressline\\
Matr.-Nr. \@matrnr\\[3mm]
\if@languagede
    Abgabedatum: \@submissiondate
\else
Date of submission: \@submissiondate
\fi

\singlespacing

\newpage

%==============================================================================

%automatically create table of contents
\tableofcontents

%next page
\newpage

%automatically create list of figures
\listoffigures

%automatically create list of tables
\listoftables

\onehalfspacing

%next page
\newpage

%remember roman page number
\newcounter{roman}
\setcounter{roman}{\value{page}}

%from here on: arabic page numbers, beginning with 1
\pagenumbering{arabic}
}

\AtEndDocument{
    
    %%%%%%%%%%%%%%%%%%%%%%%% References %%%%%%%%%%%%%
    \newpage
    \if@languagede
        \bibliographystyle{bib/Prod_Seminar_de}
    \else
        \bibliographystyle{bib/Prod_Seminar_en}
    \fi
    \bibliography{bib/Literatur}
    %%%%%%%%%%%%%%%%%%%%%%%%% End of References %%%%%

    \newpage
    %%%%%%%%%%%%%%%%%%% Affidavit / Eidesstattliche Erklärung %%%%%%%
    \section*{Eidesstattliche Erklärung}
    \thispagestyle{empty}
    Hiermit versichere ich, dass die 
    \if@bachelorthesis
        Bachelorarbeit
    \else
        \if@masterthesis
            Masterarbeit
        \else
            Seminararbeit
        \fi
    \fi
    mit dem Titel ``\StrSubstitute{\@title}{\\}{ }",
    vorgelegt am Lehrstuhl für ABWL und Produktion der Universität Mannheim, von mir persönlich
    verfasst wurde und dass ich keinerlei fremde Hilfe in Anspruch genommen habe.
    Ebenso versichere ich, dass diese Arbeit oder Teile daraus weder von mir selbst
    noch von anderen als Leistungsnachweise andernorts eingereicht wurde.
    Wörtliche oder sinngemäße Übernahmen aus anderen Schriften und Veröffentlichungen
    in gedruckter oder elektronischer Form sind gekennzeichnet. Sämtliche Sekundärliteratur
    und sonstige Quellen sind nachgewiesen und in der Bibliographie aufgeführt.
    Das Gleiche gilt für grafische Darstellungen und Bilder sowie für alle Internet-Quellen.
    
    
    Ich bin ferner damit einverstanden, dass meine Arbeit zum Zwecke eines Plagiatsabgleichs
    in elektronischer Form anonymisiert versendet und gespeichert werden kann.
    Mir ist bekannt, dass von der Korrektur der Arbeit abgesehen werden kann,
    wenn die Erklärung nicht erteilt wird.

    \vspace{5mm}

    Mannheim, den \@submissiondate

\vspace{20mm}

\@author
%%%%%%%%%%%%%%%%%%%%%%%%% End of Affidavit / Eidesstattliche Erklärung %%%%%%%
}
